@@ -1,6 +1,6 @@
 # -*- coding: latin-1 -*-
 
-"""testapi - is a package that provides an api to run any kind of generic test
+"""package that provides an api to run any kind of generic test
 
 This api, should be enough to test any kind of system, including server side commands 
 and Web UI interfaces   
